using System;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.ComponentModel;
using System.Text;
using System.Xml;

namespace NeoCore.PanelControl {
	/// <summary>
	/// Summary description for XMSPanelTextBox.
	/// </summary>
	[DefaultProperty("Text"), 
	ToolboxData("<{0}:XMSPanelDataGrid runat=server></{0}:XMSPanelDataGrid>")]
	public class XMSPanelDataGrid : DataGrid, XMSControl {
		private string rowName = "DataRow";
		private string datasetName = "NewDataSet";

		[Category("Text")]
		[Description("The name of the DataRow element.")]
		public string RowName {
			get {
				return rowName;
			}
			set {
				rowName = value;
			}
		}

		[Category("Text")]
		[Description("The name of the DataSet.")]
		public string DataSetName {
			get {
				return datasetName;
			}
			set {
				datasetName = value;
			}
		}

		/// <summary>
		/// ToXML returns the Xml string this control represents
		/// </summary>
		/// <returns>The xml string</returns>
		public string ToXML() {
			StringBuilder sb = new StringBuilder();
			System.Data.DataSet ds = (System.Data.DataSet)this.DataSource;
			XmlDataDocument dataDoc = new XmlDataDocument(ds);
			if (dataDoc.FirstChild != null) {
				sb.Append( "<" + this.ID + ">" );
				sb.Append( dataDoc.FirstChild.InnerXml );
				sb.Append( "</" + this.ID + ">" );
			}
			return sb.ToString();
		}

		/// <summary>
		/// SetData sets the data for this control
		/// </summary>
		/// <param name="data">The data to set</param>
		public void SetData(string data) {
			System.Data.DataSet ds = new System.Data.DataSet(DataSetName);
			ds.ReadXml(new System.IO.StringReader("<"+DataSetName+">" + data + "</"+DataSetName+">"));
			this.DataSource = ds;
			this.DataBind();		
		}

		/// <summary>
		/// ToXPathPredicate creates a predicate in the form of myName="myValue" and returns that string
		/// </summary>
		/// <param name="prependValue">The which needs to be prepended to the myName to fully represent the path</param>
		/// <returns>The predicate string</returns>
		public string ToXPathPredicate(string prependValue) {
			return "";
		}

		/// <summary>
		/// Clear data from the control
		/// </summary>
		public void Clear() {
			this.DataSource = null;
			this.DataBind();
		}

	}
}
